@@ -17,7 +17,7 @@
 # License along with JayDeBeApi.  If not, see
 # <http://www.gnu.org/licenses/>.
 
-__version_info__ = (1, 2, 1)
+__version_info__ = (1, 2, 2)
 __version__ = ".".join(str(i) for i in __version_info__)
 
 import datetime
@@ -663,12 +663,29 @@ def _java_to_py(java_method):
         return getattr(java_val, java_method)()
     return to_py
 
+def _java_to_py_bigdecimal():
+    def to_py(rs, col):
+        java_val = rs.getObject(col)
+        if java_val is None:
+            return
+        if hasattr(java_val, 'scale'):
+            scale = java_val.scale()
+            if scale == 0:
+                return java_val.longValue()
+            else:
+                return java_val.doubleValue()
+        else:
+            return float(java_val)
+    return to_py
+
 _to_double = _java_to_py('doubleValue')
 
 _to_int = _java_to_py('intValue')
 
 _to_boolean = _java_to_py('booleanValue')
 
+_to_decimal = _java_to_py_bigdecimal()
+
 def _init_types(types_map):
     global _jdbc_name_to_const
     _jdbc_name_to_const = types_map
@@ -698,8 +715,8 @@ _DEFAULT_CONVERTERS = {
     'TIME': _to_time,
     'DATE': _to_date,
     'BINARY': _to_binary,
-    'DECIMAL': _to_double,
-    'NUMERIC': _to_double,
+    'DECIMAL': _to_decimal,
+    'NUMERIC': _to_decimal,
     'DOUBLE': _to_double,
     'FLOAT': _to_double,
     'TINYINT': _to_int,
